ToDus client
============

.. image:: https://img.shields.io/pypi/v/todus.svg
   :target: https://pypi.org/project/todus

.. image:: https://img.shields.io/pypi/pyversions/todus.svg
   :target: https://pypi.org/project/todus

.. image:: https://pepy.tech/badge/todus
   :target: https://pepy.tech/project/todus

.. image:: https://img.shields.io/pypi/l/todus.svg
   :target: https://pypi.org/project/todus

.. image:: https://github.com/adbenitez/todus/actions/workflows/python-ci.yml/badge.svg
   :target: https://github.com/adbenitez/todus/actions/workflows/python-ci.yml

.. image:: https://img.shields.io/badge/code%20style-black-000000.svg
   :target: https://github.com/psf/black

Use the ToDus API in your Python projects.

Install
-------

To install run::

  pip install todus
